@@ -5,7 +5,7 @@ use bevy::prelude::*;
 use heron::*;
 
 fn main() {
-    App::build()
+    App::new()
         .add_plugins(DefaultPlugins)
         .add_plugin(PhysicsPlugin::default()) // Add the plugin
         .insert_resource(Gravity::from(Vec2::new(0.0, -600.0))) // Define the gravity
@@ -14,7 +14,7 @@ fn main() {
         .run();
 }
 
-fn spawn(mut commands: Commands, mut materials: ResMut<Assets<ColorMaterial>>) {
+fn spawn(mut commands: Commands) {
     commands.spawn_bundle(OrthographicCameraBundle::new_2d());
 
     // The ground
@@ -22,8 +22,11 @@ fn spawn(mut commands: Commands, mut materials: ResMut<Assets<ColorMaterial>>) {
     commands
         // Spawn a bundle that contains at least a `GlobalTransform`
         .spawn_bundle(SpriteBundle {
-            sprite: Sprite::new(size),
-            material: materials.add(Color::WHITE.into()),
+            sprite: Sprite {
+                color: Color::WHITE,
+                custom_size: Some(size),
+                ..Default::default()
+            },
             transform: Transform::from_translation(Vec3::new(0.0, -300.0, 0.0)),
             ..Default::default()
         })
@@ -45,8 +48,11 @@ fn spawn(mut commands: Commands, mut materials: ResMut<Assets<ColorMaterial>>) {
     commands
         // Spawn a bundle that contains at least a `GlobalTransform`
         .spawn_bundle(SpriteBundle {
-            sprite: Sprite::new(size),
-            material: materials.add(Color::GREEN.into()),
+            sprite: Sprite {
+                color: Color::GREEN,
+                custom_size: Some(size),
+                ..Default::default()
+            },
             transform: Transform::from_translation(Vec3::new(-400.0, 200.0, 0.0)),
             ..Default::default()
         })
